@@ -1,7 +1,7 @@
 /*
     Numdiff - compare putatively similar files, 
     ignoring small numeric differences
-    Copyright (C) 2005,2006  Ivano Primi  <ivprimi@libero.it>
+    Copyright (C) 2005-2007  Ivano Primi  <ivprimi@libero.it>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -239,24 +239,9 @@ int cmp_fields (const char* field1, const char* field2,
     }
 }
 
-int cmp_lines (const char* line1, const char* line2, 
-	       unsigned long lineno, argslist* argl)
+int cmp_lines (const char* line1, const char* line2, unsigned long lineno, 
+	       char* ifs, int output_mode, argslist* argl)
 {
-  int output_mode = OUTMODE_NORMAL;
-  char* ifs;
-
-  if (!argl->ifs)
-    ifs = IFS;
-  else
-    ifs = argl->ifs;
-
-  if ( argl->optmask & _SV_MASK )
-    output_mode = OUTMODE_VERBOSE;
-  if ( argl->optmask & _B_MASK )
-    output_mode = OUTMODE_BRIEF;
-  if ( argl->optmask & _Q_MASK )
-    output_mode = OUTMODE_QUIET;
-
   if (!line1 && !line2)
     return 0;
   else if (!line1)
@@ -310,7 +295,8 @@ int cmp_lines (const char* line1, const char* line2,
 		      if ((_1sttime))
 			{
 			  print_lines (line1, line2, lineno, 
-				       output_mode < OUTMODE_VERBOSE);
+				       output_mode != OUTMODE_VERBOSE &&
+				       output_mode != OUTMODE_COINCISE);
 			  _1sttime = 0;
 			}
 		      print_fields (field1, field2, l1, l2, lineno, fieldno);
@@ -368,10 +354,24 @@ int cmp_lines (const char* line1, const char* line2,
 
 int cmp_files (FILE* pf1, FILE* pf2, argslist* argl)
 {
-  char *line1, *line2;
-  int err1, err2, files_differ = 0;
+  char *line1, *line2, *ifs;
+  int output_mode = OUTMODE_NORMAL, err1, err2, files_differ = 0;
   unsigned long lineno = 1;
 
+  if (!argl->ifs)
+    ifs = IFS;
+  else
+    ifs = argl->ifs;
+
+  if ( argl->optmask & _SV_MASK )
+    output_mode = OUTMODE_VERBOSE;
+  if ( argl->optmask & _B_MASK )
+    output_mode = OUTMODE_BRIEF;
+  if (argl->optmask & _B_MASK && argl->optmask & _SV_MASK)
+    output_mode = OUTMODE_COINCISE;
+  if ( argl->optmask & _Q_MASK )
+    output_mode = OUTMODE_QUIET;
+
   do
     {
       line1 = read_line (pf1, &err1);
@@ -385,7 +385,7 @@ int cmp_files (FILE* pf1, FILE* pf2, argslist* argl)
       */
       if ( argl->firstln <= lineno && lineno <= argl->lastln ) 
 	{
-	  if ( (cmp_lines (line1, line2, lineno, argl)) )
+	  if ( (cmp_lines (line1, line2, lineno, ifs, output_mode, argl)) )
 	    files_differ = 1;
 	}
       if ((line1))
