@@ -1,7 +1,7 @@
 /*
     Numdiff - compare putatively similar files, 
     ignoring small numeric differences
-    Copyright (C) 2005,2006  Ivano Primi  <ivprimi@libero.it>
+    Copyright (C) 2005-2007  Ivano Primi  <ivprimi@libero.it>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -201,11 +201,12 @@ typedef struct {
 /* Do not change the relative order of the values of   */
 /* these macros, the code in cmp_lines()  (see file    */
 /* cmpfns.c) relies on the fact that:                  */
-/* OUTMODE_VERBOSE > OUTMODE_NORMAL > OUTMODE_BRIEF >  */
-/* > OUTMODE_QUIET  .                                  */
+/* OUTMODE_VERBOSE > OUTMODE_NORMAL > OUTMODE_COINCISE */
+/* > OUTMODE_BRIEF > OUTMODE_QUIET  .                  */
 
-#define OUTMODE_VERBOSE     3
-#define OUTMODE_NORMAL      2
+#define OUTMODE_VERBOSE     4
+#define OUTMODE_NORMAL      3
+#define OUTMODE_COINCISE    2
 #define OUTMODE_BRIEF       1
 #define OUTMODE_QUIET       0
 
