@@ -1,7 +1,7 @@
 /*
     Numdiff - compare putatively similar files, 
     ignoring small numeric differences
-    Copyright (C) 2005,2006  Ivano Primi  <ivprimi@libero.it>
+    Copyright (C) 2005-2007  Ivano Primi  <ivprimi@libero.it>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ void print_version (const char* progname)
   };
 
   printf ("%s %s\n", progname, VERSION);
-  printf (_("Copyright (C) 2005,2006  %s <ivprimi@libero.it>\n"), 
+  printf (_("Copyright (C) 2005-2007  %s <ivprimi@libero.it>\n"), 
 	  /* TRANSLATORS: This is a proper name.  See the gettext
 	     manual, section Names.
 	     Pronounciation is like "evaa-no pree-me".  */
@@ -86,7 +86,7 @@ void print_help (const char* progname)
 {
   puts (_("Usage:"));
   printf ("%s -h|v   %s\n\n", progname, _("or"));
-  printf ("%s %s\n", progname, _("[-a maxerr][-r maxerr][-2][-P][-N][-s ifs][-b][-V][-q][-D][-E][-I][-S][-# prec][-d c1c2][-t c1c2][-g n1n2][-p c1c2][-n c1c2][-e c1c2][-i c1c2][-F f1-f2][-L l1-l2][-l path][-o path] FILE1 FILE2"));
+  printf ("%s %s\n", progname, "[-a maxerr][-r maxerr][-2][-P][-N][-s ifs][-b][-V][-q][-D][-E][-I][-S][-# prec][-d c1c2][-t c1c2][-g n1n2][-p c1c2][-n c1c2][-e c1c2][-i c1c2][-F f1-f2][-L l1-l2][-l path][-o path] FILE1 FILE2");
   /* %%% */
   printf (_("\nCompare putatively similar files line by line and field by field,\nignoring small numeric differences or/and different numeric formats\n\n"));
   printf ("-a maxerr %s\n          %s\n", 
