@@ -1,6 +1,6 @@
 #!/bin/bash
 #  This script is part of Numdiff
-#  Copyright (C)  2005,2006    Ivano Primi  <ivprimi@libero.it>    
+#  Copyright (C)  2005-2007    Ivano Primi  <ivprimi@libero.it>    
 #
 #   Copying and distribution of this file, with or without modification,
 #   are permitted in any medium without royalty provided the copyright
@@ -16,8 +16,7 @@ echo "Viewer: $LESS"
 echo "Tester program: $DIFF"
 echo "Numdiff: $NUMDIFF"
 
-TESTS="test1 test2 test3 test4 test5 test6 test7 test8"
-#TESTS="test1 test4 test7"
+TESTS="test1 test2 test3 test4 test5 test6 test7 test8 test9"
 
 for TEST in $TESTS
 do
